@@ -21,9 +21,11 @@ __license__ = "gpl3"
 
 def gather_extract_params(args):
     params = [name for name, arg in zip(
-        ('measures', 'notes', 'rests', 'labels', 'expanded', 'form_labels', 'events', 'chords', 'metadata'),
-        (args.measures, args.notes, args.rests, args.labels, args.expanded, args.form_labels, args.events, args.chords, args.metadata))
+        ('measures', 'notes', 'rests', 'labels', 'expanded', 'form_labels', 'events', 'chords'),
+        (args.measures, args.notes, args.rests, args.labels, args.expanded, args.form_labels, args.events, args.chords))
               if arg]
+    if args.metadata is not None:
+        params.append('metadata')
     return params
 
 
@@ -123,19 +125,18 @@ def convert_cmd(args):
             update_logger.info(f"Argument '{argument_name}' is currently being ignored.")
     out_dir = os.getcwd() if args.out is None else resolve_dir(args.out)
     ms = 'auto' if args.musescore is None else args.musescore
-    for directory in args.dir:
-        convert_folder(directory=directory,
-                       paths=args.files,
-                       target_dir=out_dir,
-                       extensions=args.extensions,
-                       target_extension=args.format,
-                       regex=args.include,
-                       suffix=args.suffix,
-                       recursive=not args.nonrecursive,
-                       ms=ms,
-                       overwrite=args.safe,
-                       parallel=not args.iterative,
-                       logger=update_logger)
+    convert_folder(directory=args.dir,
+                   paths=args.files,
+                   target_dir=out_dir,
+                   extensions=args.extensions,
+                   target_extension=args.format,
+                   regex=args.include,
+                   suffix=args.suffix,
+                   recursive=not args.nonrecursive,
+                   ms=ms,
+                   overwrite=args.safe,
+                   parallel=not args.iterative,
+                   logger=update_logger)
 
 def empty(args):
     logger_cfg = {
@@ -181,37 +182,27 @@ def extract_cmd(args, parse_obj: Optional[Parse] = None):
             silence_label_warnings=silence_label_warnings,
             **suffixes)
 
-def metadata(args):
+def metadata(args, parse_obj: Optional[Parse] = None):
     """ Update MSCX files with changes made in metadata.tsv (created via ms3 extract -D). In particular,
         add the values from (new?) columns to the corresponding fields in the MuseScore files' "Score info".
     """
-    logger_cfg = {
-        'level': args.level,
-        'path': args.log,
-    }
-
-    regex = r'(metadata\.tsv|\.mscx)$' if args.regex == '(\.mscx|\.mscz|\.tsv)$' else args.regex
-
-    p = Parse(args.dir, recursive=not args.nonrecursive, file_re=regex, exclude_re=args.exclude, paths=args.file, **logger_cfg)
-    if not any('metadata' in fnames for fnames in p.fnames.values()):
-        p.logger.info("metadata.tsv not found.")
-        return
-    p.parse(parallel=False)
-    if len(p._metadata) == 0:
-        p.logger.info("No suitable metadata recognized.")
-        return
-    ids = p.update_metadata() # Writes info to parsed MuseScore files
-    if len(ids) == 0:
-        p.logger.debug("Nothing to update.")
-        return
-    if args.out is not None:
-        p.store_scores(ids=ids, root_dir=args.out, overwrite=True)
+    if parse_obj is None:
+        p = make_parse_obj(args)
     else:
-        p.store_scores(ids=ids, overwrite=True)
-    if args.out is not None:
-        p.store_extracted_facets(metadata_suffix=args.out)
-    elif args.dir is not None:
-        p.store_extracted_facets(metadata_suffix=args.dir)
+        p = parse_obj
+    p.parse_scores(parallel=False)
+    modified_score_files = p.update_score_metadata_from_tsv(write_empty_values=args.empty,
+                                                            remove_unused_fields=args.remove)
+    if len(modified_score_files) == 0:
+        print("Nothing to update.")
+        return
+    corpus2paths = store_scores(p,
+                                root_dir=args.out,
+                                folder='.',
+                                simulate=args.test,
+                                suffix=args.suffix)
+    changed = sum(map(len, corpus2paths.values()))
+    print(f"Operation resulted in {changed} updated score{'s' if changed != 1 else ''}.")
 
 
 def repair(args):
@@ -351,16 +342,16 @@ def review_cmd(args,
                 report_path = os.path.join(file.corpus_path, 'reviewed', file.fname + '_reviewed.tsv')
                 write_tsv(df, report_path)
         report = pd.concat(dataframes, keys=keys)
-        warning_selection = report.count_ratio > args.threshold
+        warning_selection = (report.count_ratio > args.threshold) & report.chord_tones.notna()
         if warning_selection.sum() > 0:
             test_passes = False
-            filtered_report = report[warning_selection]
+            filtered_report = report[warning_selection].droplevel(-1)
             pretty_report = filtered_report.to_string(columns=['mc', 'mn', 'mc_onset', 'label', 'chord_tones', 'added_tones', 'n_colored', 'n_untouched', 'count_ratio'])
             logger.warning(pretty_report,
                            extra={'message_id': (19,)})
             with open(warnings_file, 'a', encoding='utf-8') as f:
                 f.write(f"Chord labels where the ratio of colored notes vs. all notes in a segment lies above {args.threshold}:\n")
-                f.write(pretty_report)
+                f.write(pretty_report + "\n")
             logger.info(f"Added the {warning_selection.sum()} labels to {warnings_file}.")
 
     # call ms3 compare
@@ -453,7 +444,7 @@ Parse('{args.dir}',
 def get_arg_parser():
     # reusable argument sets
     parse_args = argparse.ArgumentParser(add_help=False)
-    parse_args.add_argument('-d', '--dir', metavar='DIR', nargs='+', default=os.getcwd(), type=check_dir,
+    parse_args.add_argument('-d', '--dir', metavar='DIR', default=os.getcwd(), type=check_dir,
                                 help='Folder(s) that will be scanned for input files. Defaults to current working directory if no individual files are passed via -f.')
     parse_args.add_argument('-o', '--out', metavar='OUT_DIR', type=check_and_create,
                                 help='Output directory.')
@@ -623,8 +614,14 @@ In particular, check DCML harmony labels for syntactic correctness.""", parents=
 
 
     metadata_parser = subparsers.add_parser('metadata',
-                                            help="Update MSCX files with changes made in metadata.tsv (created via ms3 extract -D).",
+                                            help="Update MSCX files with changes made to metadata.tsv (created via ms3 extract -D [-a]).",
                                             parents=[parse_args])
+    metadata_parser.add_argument('--empty', action='store_true',
+                                  help="Set this flag to also allow empty values to be used for overwriting existing ones.")
+    metadata_parser.add_argument('--remove', action='store_true',
+                                  help="Set this flag to remove non-default metadata fields that are not columns in the metadata.tsv file anymore.")
+    metadata_parser.add_argument('-s', '--suffix', metavar='SUFFIX',
+                            help='Suffix of the new scores with updated metadata fields.')
     metadata_parser.set_defaults(func=metadata)
 
     repair_parser = subparsers.add_parser('repair',
