@@ -50,6 +50,8 @@ class MessageType(Enum):
     BEGINNING_WITHOUT_TIME_SIGNATURE_WARNING = 24 # no timesig in more than only the first measure (which could be an incipit)
     INVALID_REPEAT_STRUCTURE = 25
     UNFOLDING_REPEATS_FAILED_WARNING = 26
+    DCML_DEFAULT_CORRECTION_WARNING = 27
+    WRONGLY_ENCODED_POSITION_WARNING = 28
 
 
 
